@@ -11,12 +11,14 @@ First of all, add `sphinx_tweet_embed` to sphinx extension list in conf.py
    extensions = ['sphinxcontrib.twitter']
 
 
-then use `tweet` directive.
+then use `tweet` directive and `tw` role.
 
 .. code-block:: rst
 
    .. tweet:: https://twitter.com/pypi/status/315214320826978305
 
+   :tw:`@shomah4a`
+
 
 finally, build your sphinx project.
 
@@ -26,7 +28,7 @@ finally, build your sphinx project.
    $ make html
 '''
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 __author__ = '@shomah4a'
 __license__ = 'LGPLv3'
 
@@ -34,7 +36,7 @@ __license__ = 'LGPLv3'
 
 def setup(app):
 
-    from . import tweet
+    from . import tweet, user
 
     app.add_javascript('http://platform.twitter.com/widgets.js')
 
@@ -42,3 +44,7 @@ def setup(app):
                  html=(tweet.visit, tweet.depart))
     app.add_directive('tweet', tweet.TweetDirective)
 
+    app.add_node(user.twnode,
+                 html=(user.visit, user.depart))
+    app.add_role('tw', user.tw_role)
+
